@@ -1,7 +1,7 @@
 # __init__.py
 
 from .executor import Translator
-from .runners import rust_runner, c_runner, java_runner, ruby_runner, lua_runner, go_runner, js_runner, php_runner, perl_runner, scala_runner, shell_runner, swift_runner, kotlin_runner, haskell_runner
+from .runners import rust_runner, c_runner, java_runner, ruby_runner, lua_runner, go_runner, js_runner, php_runner, perl_runner, scala_runner, shell_runner, kotlin_runner
 
 __all__ = [
     'Translator',
@@ -16,7 +16,5 @@ __all__ = [
     'perl_runner',
     'scala_runner',
     'shell_runner',
-    'swift_runner',
     'kotlin_runner',
-    # 'haskell_runner'
 ]
